@@ -1345,16 +1345,10 @@ var AST_PropAccess = DEFNODE("PropAccess", "expression optional property", {
         optional: "[boolean] whether the expression is optional chaining",
         property: "[AST_Node|string] the property to access.  For AST_Dot this is always a plain string, while for AST_Sub it's an arbitrary AST_Node",
     },
-    getProperty: function() {
+    get_property: function() {
         var p = this.property;
-        if (p instanceof AST_Constant) {
-            return p.value;
-        }
-        if (p instanceof AST_UnaryPrefix
-            && p.operator == "void"
-            && p.expression instanceof AST_Constant) {
-            return;
-        }
+        if (p instanceof AST_Constant) return p.value;
+        if (p instanceof AST_UnaryPrefix && p.operator == "void" && p.expression instanceof AST_Constant) return;
         return p;
     },
     _validate: function() {
@@ -1759,11 +1753,11 @@ var AST_SymbolLambda = DEFNODE("SymbolLambda", null, {
 
 var AST_SymbolDefClass = DEFNODE("SymbolDefClass", null, {
     $documentation: "Symbol defining a class",
-}, AST_SymbolLet);
+}, AST_SymbolConst);
 
 var AST_SymbolClass = DEFNODE("SymbolClass", null, {
     $documentation: "Symbol naming a class expression",
-}, AST_SymbolLet);
+}, AST_SymbolConst);
 
 var AST_SymbolCatch = DEFNODE("SymbolCatch", null, {
     $documentation: "Symbol naming the exception in catch",
